@@ -40,10 +40,10 @@ from deepcell.applications import Application
 
 
 MODEL_PATH = ('https://deepcell-data.s3-us-west-1.amazonaws.com/'
-              'saved-models/TrackingModel-4.tar.gz')
+              'saved-models/TrackingModel-5.tar.gz')
 
 ENCODER_PATH = ('https://deepcell-data.s3-us-west-1.amazonaws.com/'
-                'saved-models/TrackingModelNE-2.tar.gz')
+                'saved-models/TrackingModelNE-3.tar.gz')
 
 
 class CellTracking(Application):
@@ -99,16 +99,16 @@ class CellTracking(Application):
 
         if self.neighborhood_encoder is None:
             archive_path = tf.keras.utils.get_file(
-                'TrackingModelNE.tgz', ENCODER_PATH,
-                file_hash='80217fdd8477f0cb827fe72e8ace6542',
+                'NuclearTrackingNE.tgz', ENCODER_PATH,
+                file_hash='3e10e2a7b473f6908f7fcf4e0de2ff29',
                 extract=True, cache_subdir='models')
             model_path = os.path.splitext(archive_path)[0]
             self.neighborhood_encoder = tf.keras.models.load_model(model_path)
 
         if model is None:
             archive_path = tf.keras.utils.get_file(
-                'TrackingModelInf.tgz', MODEL_PATH,
-                file_hash='2a4d08eb610999563f6a8f06692f8783',
+                'NuclearTrackingInf.tgz', MODEL_PATH,
+                file_hash='fd3770c86508524762e56f01d9d7c4d2',
                 extract=True, cache_subdir='models')
             model_path = os.path.splitext(archive_path)[0]
             model = tf.keras.models.load_model(model_path)
